import * as moment_ from 'moment';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Component, ElementRef, EventEmitter, HostListener, Input, Output, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = moment_;
// fixes package build error
class AngularSimpleDatePickerComponent {
    /**
     * Component constructor
     * @param {?} elmRef
     */
    constructor(elmRef) {
        this.elmRef = elmRef;
        this.dayNames = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
        this.closeEnabled = true;
        this.dateChange = new EventEmitter();
        this.dates = new Array();
        this.activeDate = moment();
        this.selectedDate = this.activeDate;
        this.initialDate = this.activeDate.format('YYYY-MM-DD');
        this.visible = false;
        this.date = '';
        this.importantDates = [];
        this.inputClass = '';
    }
    /**
     * Events
     * @param {?} event
     * @return {?}
     */
    clickInside(event) {
        this.closeEnabled = false;
    }
    /**
       * Getters & setters
       */
    /**
     * Lifecycle hooks
     * @return {?}
     */
    ngOnChanges() {
        this.generateCalendar();
        this.generateMonthList();
        if (this.date) {
            this.buildActiveDate(null, null, null, this.date);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        if (this.showMonthSelector || this.showYearSelector) {
            return false;
        }
        if (!this.elmRef.nativeElement.contains(event.target) && this.closeEnabled) {
            this.closePicker();
        }
        this.closeEnabled = true;
    }
    /**
     * Component Methods
     * @param {?} date
     * @return {?}
     */
    setSelected(date) {
        /** @type {?} */
        let selected = false;
        if (this.date && this.date === date) {
            selected = true;
        }
        else if (!this.date && this.initialDate === date) {
            selected = true;
        }
        else {
            selected = false;
        }
        return selected;
    }
    /**
     * @return {?}
     */
    closePicker() {
        this.visible = false;
    }
    /**
     * @param {?} date
     * @return {?}
     */
    setDate(date) {
        if (date.offset === null) {
            return;
        }
        this.selectedDate = date.fullDate;
        this.initialDate = '';
        this.dateChange.emit(date.fullDate);
        this.closePicker();
    }
    /**
     * @param {?} evt
     * @return {?}
     */
    closeMonthSelector(evt) {
        this.showMonthSelector = evt;
    }
    /**
     * @param {?} evt
     * @return {?}
     */
    closeYearSelector(evt) {
        this.showYearSelector = evt;
    }
    /**
     * @param {?} evt
     * @return {?}
     */
    updateMonth(evt) {
        /** @type {?} */
        const month = evt;
        this.buildActiveDate(null, month, null, null);
    }
    /**
     * @param {?} evt
     * @return {?}
     */
    updateYear(evt) {
        /** @type {?} */
        const year = evt;
        /** @type {?} */
        const month = this.activeDate.month();
        this.buildActiveDate(year, month + 1, null, null);
    }
    /**
     * @param {?=} date
     * @return {?}
     */
    getActiveDate(date = this.activeDate) {
        /** @type {?} */
        const activeMonth = moment(date).format('MMMM');
        /** @type {?} */
        const activeYear = moment(date).format('YYYY');
        return {
            month: activeMonth,
            year: activeYear
        };
    }
    /**
     * @return {?}
     */
    getPrevMonth() {
        /** @type {?} */
        const prevMonth = this.activeDate.subtract(1, 'months');
        this.setActiveDate(prevMonth);
    }
    /**
     * @return {?}
     */
    getNextMonth() {
        /** @type {?} */
        const nextMonth = this.activeDate.add(1, 'months');
        this.setActiveDate(nextMonth);
    }
    /**
     * @private
     * @param {?=} year
     * @param {?=} month
     * @param {?=} date
     * @param {?=} fullDate
     * @return {?}
     */
    buildActiveDate(year = null, month = null, date = null, fullDate = null) {
        if (fullDate) {
            this.setActiveDate(fullDate);
            return;
        }
        if (this.date) {
            this.setActiveDate(this.date);
        }
        /** @type {?} */
        const currentYear = moment(this.activeDate).year();
        /** @type {?} */
        const currentMonth = moment(this.activeDate).month();
        /** @type {?} */
        const currentDate = moment(this.activeDate).date();
        /** @type {?} */
        const newYear = year === null ? currentYear : year;
        /** @type {?} */
        let newMonth = month === null ? currentMonth : month;
        /** @type {?} */
        let newDate = date === null ? currentDate : date;
        newMonth = newMonth < 10 ? '0' + newMonth : newMonth;
        newDate = newDate < 10 ? '0' + newDate : newDate;
        /** @type {?} */
        const daysInMonth = moment(`${currentYear}-${newMonth}`, 'YYYY-MM').daysInMonth();
        if (newDate > daysInMonth)
            newDate = daysInMonth;
        /** @type {?} */
        const activeDate = `${newYear}-${newMonth}-${newDate}`;
        this.setActiveDate(activeDate);
        this.dateChange.emit(activeDate);
    }
    /**
     * @private
     * @param {?} date
     * @return {?}
     */
    setActiveDate(date) {
        this.activeDate = moment(date, 'YYYY-MM-DD');
        this.generateCalendar();
    }
    /**
     * @private
     * @return {?}
     */
    setOffset() {
        /** @type {?} */
        const offset = this.dates[0].offset;
        /** @type {?} */
        const blankDay = {
            dayName: '',
            dayOfMonth: '00',
            fullDate: '',
            offset: null,
            isImportant: false
        };
        if (offset !== null) {
            for (let i = 0; i < offset; i++) {
                this.dates.unshift(blankDay);
            }
        }
        /** @type {?} */
        const endOffset = 40 - this.dates.length;
        for (let i = 0; i < endOffset; i++) {
            this.dates.push(blankDay);
        }
    }
    /**
     * @private
     * @return {?}
     */
    generateMonthList() {
        /** @type {?} */
        const monthList = new Array();
        /** @type {?} */
        const months = moment.monthsShort();
        months.forEach((/**
         * @param {?} month
         * @param {?} idx
         * @return {?}
         */
        (month, idx) => {
            monthList.push({
                name: month,
                index: idx + 1
            });
        }));
        this.monthList = monthList;
    }
    /**
     * @private
     * @param {?=} direction
     * @return {?}
     */
    generateCalendar(direction = null) {
        /** @type {?} */
        const currentDate = moment(this.activeDate);
        /** @type {?} */
        const month = moment(currentDate).month() + 1;
        /** @type {?} */
        const year = currentDate.year();
        /** @type {?} */
        const startOfMonth = moment(currentDate).startOf('month');
        /** @type {?} */
        const endOfMonth = moment(currentDate).endOf('month');
        /** @type {?} */
        const dates = new Array();
        for (let i = startOfMonth.date(); i <= endOfMonth.date(); i++) {
            /** @type {?} */
            const date = `${month}/${i}/${year}`.toString();
            /** @type {?} */
            const fullDate = moment(date, 'MM/D/YYYY').format('YYYY-MM-DD');
            /** @type {?} */
            const day = fullDate.split('-')[2];
            /** @type {?} */
            const important = this.importantDates !== null ? this.importantDates.includes(fullDate) : false;
            dates.push({
                dayName: this.dayNames[startOfMonth.day()],
                dayOfMonth: day,
                fullDate: fullDate,
                offset: moment(fullDate).day(),
                isImportant: important
            });
            startOfMonth.add(1, 'days');
        }
        this.dates = dates;
        this.setOffset();
    }
}
AngularSimpleDatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'simple-date-picker',
                template: "<div *ngIf=\"date\">\n  <button\n    class=\"{{ inputClass }} simple-picker-input\"\n    (click)=\"visible = !visible\"\n  >\n    {{ date | date }}\n  </button>\n  <div>\n    <div class=\"simple-picker\" *ngIf=\"visible\">\n      <simple-year-selector\n        (yearSelected)=\"updateYear($event)\"\n        (close)=\"closeYearSelector($event)\"\n        *ngIf=\"showYearSelector\"\n      ></simple-year-selector>\n      <simple-month-selector\n        [monthList]=\"monthList\"\n        (monthSelected)=\"updateMonth($event)\"\n        [currentDate]=\"getActiveDate()\"\n        (close)=\"closeMonthSelector($event)\"\n        *ngIf=\"showMonthSelector\"\n      >\n      </simple-month-selector>\n      <header class=\"simple-picker-header\">\n        <div\n          (click)=\"getPrevMonth()\"\n          class=\"simple-picker-nav-btn simple-picker-nav-btn-left\"\n        >\n          <i class=\"simple-picker-icon simple-picker-arrow-left\"></i>\n        </div>\n        <div\n          (click)=\"getNextMonth()\"\n          class=\"simple-picker-nav-btn simple-picker-nav-btn-right\"\n        >\n          <i class=\"simple-picker-icon simple-picker-arrow-right\"></i>\n        </div>\n        <div class=\"simple-picker-date\">\n          <span (click)=\"showMonthSelector = true\" class=\"simple-picker-action\">\n            {{ getActiveDate().month }}\n          </span>\n          <span\n            (click)=\"showYearSelector = true\"\n            class=\"simple-picker-action\"\n            >{{ getActiveDate().year }}</span\n          >\n        </div>\n        <div class=\"simple-picker-day-names clear-fix\">\n          <div *ngFor=\"let dayName of dayNames\" class=\"simple-picker-day-name\">\n            {{ dayName }}\n          </div>\n        </div>\n      </header>\n      <div class=\"simple-picker-body clear-fix\">\n        <div\n          *ngFor=\"let date of dates\"\n          (click)=\"setDate(date)\"\n          class=\"simple-picker-day-box\"\n          [ngClass]=\"{\n            'simple-picker-empty': date.offset === null,\n            'simple-picker-highlighted': date.isImportant,\n            'simple-picker-selected': setSelected(date.fullDate)\n          }\"\n        >\n          {{ date.dayOfMonth }}\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n<div *ngIf=\"date == undefined\">\n  <p>Error: `date` is required, value cannot be null or undefined.</p>\n</div>\n",
                host: {
                    '(document:click)': 'onClick($event)',
                },
                styles: [".simple-picker-nav-btn{position:absolute;top:0;padding:14px 11px;z-index:5}.simple-picker-nav-btn.simple-picker-nav-btn-left{left:0}.simple-picker-nav-btn.simple-picker-nav-btn-right{right:0}.simple-picker-nav-btn:hover{cursor:pointer}.simple-picker-nav-btn:hover .simple-picker-icon{border-color:#fff}.simple-picker-icon{display:inline-block;padding:3px;border:solid rgba(255,255,255,.5);border-width:0 3px 3px 0}.simple-picker-icon:hover{border-color:#fff}.simple-picker-icon.simple-picker-arrow-right{transform:scale(.9,.9) rotate(-45deg)}.simple-picker-icon.simple-picker-arrow-left{transform:scale(.9,.9) rotate(135deg)}.simple-picker-action{cursor:pointer;padding:3px 5px;line-height:1;display:inline-block}.simple-picker-action:hover{background-color:#555}.clear-fix:before{display:table;content:\" \"}.clear-fix:after{display:table;content:\" \";clear:both}.simple-picker{position:absolute;z-index:100;font-family:Museo;font-size:12px;width:250px;height:auto;background-color:#fff;box-shadow:0 2px 5px rgba(0,0,0,.1)}.simple-picker *{box-sizing:border-box}.simple-picker-input{padding:8px;width:100%;cursor:pointer;max-width:300px;font-size:16px;font-weight:700;font-family:'Source Sans Pro','Helvetica Neue',Helvetica,Arial,sans-serif;background:url(\"data:image/svg+xml;charset=utf8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 5'><path fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/></svg>\") right 8px center/8px 8px no-repeat,url(\"data:image/svg+xml,%0A%3Csvg viewBox='0 0 1792 1792' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M192 1664h288v-288h-288v288zm352 0h320v-288h-320v288zm-352-352h288v-320h-288v320zm352 0h320v-320h-320v320zm-352-384h288v-288h-288v288zm736 736h320v-288h-320v288zm-384-736h320v-288h-320v288zm768 736h288v-288h-288v288zm-384-352h320v-320h-320v320zm-352-864v-288q0-13-9.5-22.5t-22.5-9.5h-64q-13 0-22.5 9.5t-9.5 22.5v288q0 13 9.5 22.5t22.5 9.5h64q13 0 22.5-9.5t9.5-22.5zm736 864h288v-320h-288v320zm-384-384h320v-288h-320v288zm384 0h288v-288h-288v288zm32-480v-288q0-13-9.5-22.5t-22.5-9.5h-64q-13 0-22.5 9.5t-9.5 22.5v288q0 13 9.5 22.5t22.5 9.5h64q13 0 22.5-9.5t9.5-22.5zm384-64v1280q0 52-38 90t-90 38h-1408q-52 0-90-38t-38-90v-1280q0-52 38-90t90-38h128v-96q0-66 47-113t113-47h64q66 0 113 47t47 113v96h384v-96q0-66 47-113t113-47h64q66 0 113 47t47 113v96h128q52 0 90 38t38 90z'/%3E%3C/svg%3E\") 10px center/16px 16px no-repeat #fff;border:1px solid #ddd;transition:.3s}.simple-picker-input:hover{box-shadow:0 1px 3px rgba(0,0,0,.1);background-color:#ddd;border-color:#aaa}.simple-picker-input:focus{outline:0}.simple-picker-input:active{background-color:#ccc}.simple-picker-header{position:relative;color:#fff;border:1px solid #222;background:#222}.simple-picker-date{font-family:\"Helvetica Neue\",Helvetica,Arial,sans-serif;font-size:16px;font-weight:700;padding:10px 0;text-align:center}.simple-picker-day-names{padding:5px 0 10px}.simple-picker-day-name{float:left;width:calc(100% / 7);text-align:center;color:#ddd}.simple-picker-body{border:1px solid #ddd;border-top:none}.simple-picker-day-box{font-family:\"Source Sans Pro\",sans-serif;float:left;width:calc(100% / 7);padding:6px 0;cursor:pointer;text-align:center;color:#666;background-color:#f5f5f5}.simple-picker-day-box.simple-picker-highlighted{color:#000;background-color:#96c93d}.simple-picker-day-box.simple-picker-selected{color:#fff;background-color:#2985ff}.simple-picker-day-box.simple-picker-empty{text-indent:-999999px;background-color:#fff}.simple-picker-day-box.simple-picker-empty:hover{cursor:default;background-color:#fff}.simple-picker-day-box:hover{color:#fff;background-color:#666}"]
            }] }
];
/** @nocollapse */
AngularSimpleDatePickerComponent.ctorParameters = () => [
    { type: ElementRef }
];
AngularSimpleDatePickerComponent.propDecorators = {
    importantDates: [{ type: Input }],
    date: [{ type: Input }],
    inputClass: [{ type: Input }],
    dateChange: [{ type: Output }],
    clickInside: [{ type: HostListener, args: ['click', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SimpleMonthSelectorComponent {
    /**
     * Component constructor
     */
    constructor() {
        /**
         * Property declarations
         */
        this._month = '';
        /**
         * Input & Output declarations
         */
        this.monthList = [];
        this.monthSelected = new EventEmitter();
        this.close = new EventEmitter();
    }
    /**
     * Events
     * @param {?} month
     * @return {?}
     */
    selectMonth(month) {
        this.monthSelected.emit(month.index);
        this.close.emit(false);
    }
    /**
     * @return {?}
     */
    onClose() {
        this.close.emit(false);
    }
    /**
     * Getters & setters
     * @param {?} month
     * @return {?}
     */
    set month(month) {
        this._month = month;
    }
    /**
     * @return {?}
     */
    get month() { return this._month; }
    /**
     * Lifecycle hooks
     * @return {?}
     */
    ngOnInit() {
        this.buildMonthTable();
    }
    /**
     * Component Methods
     * @private
     * @return {?}
     */
    buildMonthTable() {
        /** @type {?} */
        const rows = [];
        /** @type {?} */
        const numRows = 4;
        /** @type {?} */
        let start = 0;
        /** @type {?} */
        let end = 4;
        for (let i = 0, len = this.monthList.length / numRows; i < len; i++) {
            /** @type {?} */
            const row = this.monthList.slice(start, end);
            start = end;
            end += 4;
            rows.push(row);
        }
        /** @type {?} */
        const sorted = rows[0].map((/**
         * @param {?} col
         * @param {?} i
         * @return {?}
         */
        (col, i) => rows.map((/**
         * @param {?} row
         * @return {?}
         */
        row => row[i]))));
        /** @type {?} */
        const monthTable = this.flattenArray(sorted);
        this.monthTable = monthTable;
    }
    /**
     * Helper methods
     * @private
     * @param {?} arr
     * @return {?}
     */
    flattenArray(arr) {
        return JSON.parse(`[${JSON.stringify(arr).replace(/\[|\]/g, '')}]`);
    }
}
SimpleMonthSelectorComponent.decorators = [
    { type: Component, args: [{
                selector: 'simple-month-selector',
                template: "<div class=\"simple-month-selector simple-picker-selector\">\n  <div class=\"simple-month-selector-close-btn\" (click)=\"onClose()\"></div>\n  <ul>\n    <li *ngFor=\"let month of monthTable\" (click)=\"selectMonth(month)\">\n      {{ month.name }}\n    </li>\n  </ul>\n</div>\n",
                styles: [".simple-picker{position:absolute;height:167px}.simple-picker-selector{position:absolute;top:0;left:0;bottom:0;width:248px;background-color:#f5f5f5;z-index:10;border:1px solid #ddd;height:234px}.simple-picker-selector *{box-sizing:border-box}.simple-picker-selector ul{position:relative;top:50%;left:50%;transform:translate(-50%,-50%);display:flex;align-items:center;justify-content:center;flex-direction:row;flex-wrap:wrap;list-style:none;padding:0 10%;margin:0;width:100%;height:70%}.simple-picker-selector ul li{color:#666;display:flex;justify-content:center;align-self:stretch;align-items:center;flex:1;flex-basis:33%;font-size:14px;text-align:center;list-style-type:none}.simple-picker-selector ul li:hover{cursor:pointer;color:#fff;background-color:#666}.simple-picker-selector [class*=close-btn]{position:absolute;padding:5px 10px;top:0;right:0;line-height:.85rem}.simple-picker-selector [class*=close-btn]:before{font-family:'Helvetica Neue',Helvetica,sans-serif;font-size:22px;font-weight:700;content:\"\\00d7\";line-height:inherit}.simple-picker-selector [class*=close-btn]:hover{cursor:pointer;background-color:#c00}.simple-picker-selector [class*=close-btn]:hover:before{color:#fff}.simple-picker-nav-btn{position:absolute;top:0;padding:14px 11px;z-index:5}.simple-picker-nav-btn.simple-picker-nav-btn-left{left:0}.simple-picker-nav-btn.simple-picker-nav-btn-right{right:0}.simple-picker-nav-btn:hover{cursor:pointer}.simple-picker-nav-btn:hover .simple-picker-icon{border-color:#fff}.simple-picker-icon{display:inline-block;padding:3px;border:solid rgba(255,255,255,.5);border-width:0 3px 3px 0}.simple-picker-icon:hover{border-color:#fff}.simple-picker-icon.simple-picker-arrow-right{transform:scale(.9,.9) rotate(-45deg)}.simple-picker-icon.simple-picker-arrow-left{transform:scale(.9,.9) rotate(135deg)}.simple-picker-action{cursor:pointer;padding:3px 5px;line-height:1;display:inline-block}.simple-picker-action:hover{background-color:#555}.clear-fix:before{display:table;content:\" \"}.clear-fix:after{display:table;content:\" \";clear:both}"]
            }] }
];
/** @nocollapse */
SimpleMonthSelectorComponent.ctorParameters = () => [];
SimpleMonthSelectorComponent.propDecorators = {
    monthList: [{ type: Input }],
    currentDate: [{ type: Input }],
    monthSelected: [{ type: Output }],
    close: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SimpleYearSelectorComponent {
    /**
     * Component constructor
     */
    constructor() {
        this.yearSelected = new EventEmitter();
        this.close = new EventEmitter();
        this.currentPage = 1;
    }
    /**
     * Events
     * @param {?} year
     * @return {?}
     */
    selectYear(year) {
        this.yearSelected.emit(year);
        this.close.emit(false);
    }
    /**
     * @return {?}
     */
    onClose() {
        this.close.emit(false);
    }
    /**
     * Getters & setters
     * @param {?} year
     * @return {?}
     */
    set year(year) { this._year = year; }
    /**
     * @return {?}
     */
    get year() { return this._year; }
    /**
     * @param {?} years
     * @return {?}
     */
    set years(years) { this._years = years; }
    /**
     * @return {?}
     */
    get years() { return this._years; }
    /**
     * Lifecycle hooks
     * @return {?}
     */
    ngOnInit() {
        this.generateYears();
        this.setPagedYears(1);
        this.getCurrentPage();
    }
    /**
     * Component Methods
     * @return {?}
     */
    generateYears() {
        /** @type {?} */
        const minYear = 100;
        /** @type {?} */
        const maxYear = 10000;
        /** @type {?} */
        const years = [];
        for (let i = maxYear; i > minYear - 1; i--) {
            years.unshift(i);
        }
        this.years = years;
        this.buildPagedYears();
    }
    /**
     * @return {?}
     */
    getPrevPage() {
        this.currentPage -= 1;
        this.setPagedYears();
    }
    /**
     * @return {?}
     */
    getNextPage() {
        this.currentPage += 1;
        this.setPagedYears();
    }
    /**
     * @return {?}
     */
    getCurrentPage() {
        /** @type {?} */
        const pagedYears = this.pagedYears;
        /** @type {?} */
        let currentPage = this.currentPage;
        pagedYears.forEach((/**
         * @param {?} years
         * @param {?} page
         * @return {?}
         */
        (years, page) => {
            years.forEach((/**
             * @param {?} year
             * @return {?}
             */
            (year) => {
                if (year === 2019) {
                    currentPage = page;
                }
            }));
        }));
        this.setPagedYears(currentPage);
    }
    /**
     * @param {?=} page
     * @return {?}
     */
    buildPagedYears(page = 1) {
        /** @type {?} */
        const years = this.years;
        /** @type {?} */
        const yearsPerPage = 24 - 9;
        /** @type {?} */
        const numPages = years.length / yearsPerPage;
        /** @type {?} */
        const pages = [];
        page--;
        for (let i = 0; i < numPages; i++) {
            pages.push(years.slice(i * yearsPerPage, (i + 1) * yearsPerPage));
        }
        this.pagedYears = pages;
    }
    /**
     * @param {?=} page
     * @return {?}
     */
    setPagedYears(page = this.currentPage) {
        this.currentPage = page;
        this.years = this.pagedYears[page];
    }
}
SimpleYearSelectorComponent.decorators = [
    { type: Component, args: [{
                selector: 'simple-year-selector',
                template: "<div class=\"simple-year-selector simple-picker-selector\">\n  <div class=\"simple-year-selector-close-btn\" (click)=\"onClose()\"></div>\n  <div\n    (click)=\"getPrevPage()\"\n    class=\"simple-picker-nav-btn simple-picker-nav-btn-left\">\n    <i class=\"simple-picker-icon simple-picker-arrow-left\"></i>\n  </div>\n  <div\n    (click)=\"getNextPage()\"\n    class=\"simple-picker-nav-btn simple-picker-nav-btn-right\">\n    <i class=\"simple-picker-icon simple-picker-arrow-right\"></i>\n  </div>\n  <ul>\n    <li *ngFor=\"let year of years\" (click)=\"selectYear(year)\">\n      {{ year }}\n    </li>\n  </ul>\n</div>\n",
                styles: [".simple-picker{position:absolute;height:167px}.simple-picker-selector{position:absolute;top:0;left:0;bottom:0;width:248px;background-color:#f5f5f5;z-index:10;border:1px solid #ddd;height:234px}.simple-picker-selector *{box-sizing:border-box}.simple-picker-selector ul{position:relative;top:50%;left:50%;transform:translate(-50%,-50%);display:flex;align-items:center;justify-content:center;flex-direction:row;flex-wrap:wrap;list-style:none;padding:0 10%;margin:0;width:100%;height:70%}.simple-picker-selector ul li{color:#666;display:flex;justify-content:center;align-self:stretch;align-items:center;flex:1;flex-basis:33%;font-size:14px;text-align:center;list-style-type:none}.simple-picker-selector ul li:hover{cursor:pointer;color:#fff;background-color:#666}.simple-picker-selector [class*=close-btn]{position:absolute;padding:5px 10px;top:0;right:0;line-height:.85rem}.simple-picker-selector [class*=close-btn]:before{font-family:'Helvetica Neue',Helvetica,sans-serif;font-size:22px;font-weight:700;content:\"\\00d7\";line-height:inherit}.simple-picker-selector [class*=close-btn]:hover{cursor:pointer;background-color:#c00}.simple-picker-selector [class*=close-btn]:hover:before{color:#fff}.simple-picker-nav-btn{position:absolute;padding:14px 11px;z-index:5;top:50%;transform:translateY(-50%)}.simple-picker-nav-btn.simple-picker-nav-btn-left{left:0}.simple-picker-nav-btn.simple-picker-nav-btn-right{right:0}.simple-picker-icon.simple-picker-arrow-right{transform:scale(.9,.9) rotate(-45deg)}.simple-picker-icon.simple-picker-arrow-left{transform:scale(.9,.9) rotate(135deg)}.simple-picker-action{cursor:pointer;padding:3px 5px;line-height:1;display:inline-block}.simple-picker-action:hover{background-color:#555}.clear-fix:before{display:table;content:\" \"}.clear-fix:after{display:table;content:\" \";clear:both}.simple-picker-nav-btn:hover{cursor:pointer}.simple-picker-nav-btn:hover .simple-picker-icon{border-color:#000}.simple-picker-icon{display:inline-block;padding:3px;border:solid rgba(0,0,0,.5);border-width:0 3px 3px 0}.simple-picker-icon:hover{border-color:#000}"]
            }] }
];
/** @nocollapse */
SimpleYearSelectorComponent.ctorParameters = () => [];
SimpleYearSelectorComponent.propDecorators = {
    currentYear: [{ type: Input }],
    yearSelected: [{ type: Output }],
    close: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularSimpleDatePickerModule {
}
AngularSimpleDatePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AngularSimpleDatePickerComponent, SimpleMonthSelectorComponent, SimpleYearSelectorComponent],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [AngularSimpleDatePickerComponent, SimpleMonthSelectorComponent, SimpleYearSelectorComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AngularSimpleDatePickerComponent, AngularSimpleDatePickerModule, SimpleMonthSelectorComponent as ɵa, SimpleYearSelectorComponent as ɵb };

//# sourceMappingURL=angular-simple-date-picker.js.map